@@ -17,7 +17,7 @@ from ipywidgets import Box, DOMWidget, CoreWidget, Text, Label, Textarea, \
     SelectMultiple, Select, Dropdown, Checkbox, HBox, \
     VBox, RadioButtons, register, Layout, widget_serialization, HTML
 from ipywidgets.widgets.trait_types import InstanceDict
-from traitlets import Int, Unicode, Dict, Bool, Union, List
+from traitlets import Int, Unicode, Dict, Bool, Union, List, Any, observe
 from IPython.display import display
 import types
 
@@ -45,6 +45,9 @@ class EasyFormComponent:
         for f in self.onChangeListeners:
             f(x)
 
+    def set_value(self, new_value):
+        self.value = new_value
+
 
 class BeakerxLayout(Layout):
     _view_module = Unicode('@jupyter-widgets/base').tag(sync=True)
@@ -205,18 +208,28 @@ class BeakerxComboBox(Dropdown, EasyFormComponent):
     _model_module_version = Unicode('*').tag(sync=True)
     _view_module_version = Unicode('*').tag(sync=True)
     editable = Bool(default_value=False).tag(sync=True)
+    value = Any(None, allow_none=True).tag(sync=True)
     original_options = Union([List(), Dict()])
     style = None
 
+    def _update_options_list(self, new_value):
+        if new_value not in self.options:
+            self.options = self.original_options[:]
+            self.options += (new_value,)
+            self._options_values = tuple(tuple(self.options))
+
     def _handle_msg(self, msg):
         if 'value' in msg['content']['data']['state']:
             value = msg['content']['data']['state']['value']
-            if msg['content']['data']['state']['value'] not in self.options:
-                self.options = self.original_options[:]
-                self.options += (msg['content']['data']['state']['value'],)
+            self._update_options_list(value)
             self.value = value
         super(BeakerxComboBox, self)._handle_msg(msg)
 
+    def set_value(self, value):
+        if self.editable:
+            self._update_options_list(value)
+        self.value = value
+
 
 class BeakerxCheckbox(Checkbox, EasyFormComponent):
     def __init__(self, **kwargs):
