@@ -170,7 +170,7 @@ class Table(BaseObject):
             return "int64"
         if isinstance(value, int):
             return "integer"
-        if "datetime" in str(object_type)  or is_date(value):
+        if "datetime" in str(object_type):
             return "time"
         if isinstance(value, str):
             return "string"
